@@ -7,7 +7,7 @@ regex = re.compile(r"Task '(.*)' (is ambiguous|not found)")
 
 @for_app('gradle', './gradlew')
 def match(command):
-    return regex.findall(command.stderr)
+    return regex.findall(command.output)
 
 
 @eager
@@ -29,6 +29,6 @@ def _get_all_tasks(gradle):
 
 
 def get_new_command(command):
-    wrong_task = regex.findall(command.stderr)[0][0]
+    wrong_task = regex.findall(command.output)[0][0]
     all_tasks = _get_all_tasks(command.script_parts[0])
     return replace_command(command, wrong_task, all_tasks)
