@@ -1,5 +1,4 @@
-from difflib import get_close_matches
-from thefuck.utils import get_all_executables, \
+from thefuck.utils import get_all_executables, get_close_matches, \
     get_valid_history_without_current, get_closest, which
 from thefuck.specific.sudo import sudo_support
 
