@@ -26,7 +26,7 @@ def get_new_command(command):
 
     available = _get_all_environments()
     if available:
-        return replace_command(command, misspelled_env, available) \
-               + [create_new]
+        return (replace_command(command, misspelled_env, available)
+                + [create_new])
     else:
         return create_new
