@@ -1,9 +1,10 @@
 import os
+from subprocess import Popen, PIPE
 from tempfile import gettempdir
 from uuid import uuid4
 from ..conf import settings
 from ..const import ARGUMENT_PLACEHOLDER, USER_COMMAND_MARK
-from ..utils import memoize
+from ..utils import DEVNULL, memoize
 from .generic import Generic
 
 
@@ -81,3 +82,10 @@ class Bash(Generic):
             content=u'eval $(thefuck --alias)',
             path=config,
             reload=u'source {}'.format(config))
+
+    def info(self):
+        """Returns the name and version of the current shell"""
+        proc = Popen(['bash', '-c', 'echo $BASH_VERSION'],
+                     stdout=PIPE, stderr=DEVNULL)
+        version = proc.stdout.read().decode('utf-8').strip()
+        return u'Bash {}'.format(version)
