@@ -82,7 +82,7 @@ class Generic(object):
         encoded = self.encode_utf8(command)
 
         try:
-            splitted = [s.replace("??", "\ ") for s in shlex.split(encoded.replace('\ ', '??'))]
+            splitted = [s.replace("??", "\\ ") for s in shlex.split(encoded.replace('\\ ', '??'))]
         except ValueError:
             splitted = encoded.split(' ')
 
@@ -131,6 +131,10 @@ class Generic(object):
                 'type', 'typeset', 'ulimit', 'umask', 'unalias', 'unset',
                 'until', 'wait', 'while']
 
+    def info(self):
+        """Returns the name and version of the current shell"""
+        return 'Generic Shell'
+
     def _create_shell_configuration(self, content, path, reload):
         return ShellConfiguration(
             content=content,
