@@ -7,7 +7,7 @@ from .generic import Generic
 
 class Tcsh(Generic):
     def app_alias(self, alias_name):
-        return ("alias {0} 'setenv TF_ALIAS {0} && "
+        return ("alias {0} 'setenv TF_SHELL tcsh && setenv TF_ALIAS {0} && "
                 "set fucked_cmd=`history -h 2 | head -n 1` && "
                 "eval `thefuck ${{fucked_cmd}}`'").format(alias_name)
 
