@@ -14,9 +14,9 @@ def read_actions():
         key = get_key()
 
         # Handle arrows, j/k (qwerty), and n/e (colemak)
-        if key in (const.KEY_UP, 'k', 'e'):
+        if key in (const.KEY_UP, const.KEY_CTRL_N, 'k', 'e'):
             yield const.ACTION_PREVIOUS
-        elif key in (const.KEY_DOWN, 'j', 'n'):
+        elif key in (const.KEY_DOWN, const.KEY_CTRL_P, 'j', 'n'):
             yield const.ACTION_NEXT
         elif key in (const.KEY_CTRL_C, 'q'):
             yield const.ACTION_ABORT
